Objects of this class is the output of the "covariates_importance" object
from the pompp_fit-class. It can be plotted which uses
the graphics package. The print method
gives a point-wise estimation, the same seen in the bacplot method.
Both plot and boxplot methods use the posterior distribution
of the importance.
# S3 method for covariates_importance
print(x, component = "intensity", ...)# S3 method for covariates_importance
plot(
x,
component = "intensity",
y = "importance",
quantiles = c(0.025, 0.5, 0.975),
...
)
# S3 method for covariates_importance
barplot(height, component = "intensity", y, ...)
# S3 method for covariates_importance
boxplot(x, component = "intensity", ...)
The invisible object.
Nothing is returned. Plot is called and drawn on the configured device.
A barplot. See barplot for details. If component is selected
as "both", only the second barplot is returned.
A boxplot. See boxplot for details. If component is selected
as "both", only the second boxplot is returned.
The covariates_importance object.
Either "intensity", "observability" or
"both".
Other parameters passed to boxplot.
Either "interval" or "density". The formal gives
vertical credible intervals, and the latter gives separate density plots
with the specified quantiles as vertical lines.
A 2- or 3-simensional vector with the desired quantiles
specified. If 3-dimensiona, the middle point is drawn as a dot when the
y parameter is set as "interval".
The covariates_importance object.
Objects of this class have two matrices where the Monte Carlo samples on the rows and parameters on the columns. One matrix is for the intensity importance and the other for the observability importance.