Learn R Programming

pompp (version 0.1.3)

pompp_prior-class: Joint prior class for the pompp package parameters

Description

Objects of this class are the joining of independent priors for Beta, Delta and LambdaStar. They can be used in the fit_pompp function.

Usage

# S4 method for pompp_prior
names(x)

# S4 method for pompp_prior $(x, name)

# S4 method for pompp_prior show(object)

# S4 method for pompp_prior print(x, ...)

# S3 method for pompp_prior print(x, ...)

# S4 method for pompp_prior $(x, name)

# S4 method for pompp_prior $(x, name) <- value

Value

names: A character vector with the model parameters names.

`$`: The requested slot's value.

`$<-`: The new object with the updated slot.

Arguments

x

The pompp_prior object.

name

The requested slot.

object

The pompp_prior object.

...

Ignored.

value

New value.

Fields

beta

An object of a class which inherits the BetaDeltaPrior S4 class with the appropriate Beta prior.

delta

An object of a class which inherits the BetaDeltaPrior S4 class with the appropriate Delta prior.

lambdaStar

An object of a class which inherits the LambdaStarPrior S4 class with the appropriate LambdaStar prior.

marksMean

An object of S4 class NormalPrior with the chosen prior for the marks mean

marksPrecision

An object of S4 class GammaPrior with the chosen prior for the marks precision