Objects of this class are the joining of independent priors for Beta, Delta
and LambdaStar. They can be used in the fit_pompp function.
# S4 method for pompp_prior
names(x)# S4 method for pompp_prior
$(x, name)
# S4 method for pompp_prior
show(object)
# S4 method for pompp_prior
print(x, ...)
# S3 method for pompp_prior
print(x, ...)
# S4 method for pompp_prior
$(x, name)
# S4 method for pompp_prior
$(x, name) <- value
names: A character vector with the model parameters
names.
`$`: The requested slot's value.
`$<-`: The new object with the updated slot.
The pompp_prior object.
The requested slot.
The pompp_prior object.
Ignored.
New value.
betaAn object of a class which inherits the BetaDeltaPrior S4
class with the appropriate Beta prior.
deltaAn object of a class which inherits the BetaDeltaPrior S4
class with the appropriate Delta prior.
lambdaStarAn object of a class which inherits the
LambdaStarPrior S4 class with the appropriate LambdaStar prior.
marksMeanAn object of S4 class NormalPrior with the chosen
prior for the marks mean
marksPrecisionAn object of S4 class GammaPrior with the chosen
prior for the marks precision